==> mfc-es-api-1.1.2-sources.jar: com/mfc/es/api/model/service/media/MediaTrailer.java <==
package com.mfc.es.api.model.service.media;

import com.mfc.es.api.model.service.base.AbstractPrintable;

/**
 * Created by Frank.Huang on 2017/3/4.
 */
public class MediaTrailer extends AbstractPrintable {
    private String source = "";
    private String type = "";
    private String keyStr = "";
    private String title = "";
    private Integer size = 0;
    private String language;

    public MediaTrailer() {
    }

    public MediaTrailer(String source, String type, String keyStr, String title, Integer size, String language) {
        this.source = source;
        this.type = type;
        this.keyStr = keyStr;
        this.title = title;
        this.size = size;
        this.language = language;
    }

    public String getSource() {
        return source;
    }

    public void setSource(String source) {
        this.source = source;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public String getKeyStr() {
        return keyStr;
    }

    public void setKeyStr(String keyStr) {
        this.keyStr = keyStr;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public Integer getSize() {
        return size;
    }

    public void setSize(Integer size) {
        this.size = size;
    }

    public String getLanguage() {
        return language;
    }

    public void setLanguage(String language) {
        this.language = language;
    }
}

==> mfc-es-api-1.3.8-sources.jar: com/mfc/es/api/model/service/media/MediaTrailer.java <==
package com.mfc.es.api.model.service.media;

import com.mfc.es.api.model.service.base.AbstractPrintable;

/**
 * Created by Frank.Huang on 2017/3/4.
 */
public class MediaTrailer extends AbstractPrintable {
    private String source = "";
    private String type = "";
    private String keyStr = "";
    private String title = "";
    private Integer size = 0;
    private String language;
    private String url;

    public MediaTrailer() {
    }

    public MediaTrailer(String source, String type, String keyStr, String title, Integer size, String language, String url) {
        this.source = source;
        this.type = type;
        this.keyStr = keyStr;
        this.title = title;
        this.size = size;
        this.language = language;
        this.url = url;
    }

    public String getSource() {
        return source;
    }

    public void setSource(String source) {
        this.source = source;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public String getKeyStr() {
        return keyStr;
    }

    public void setKeyStr(String keyStr) {
        this.keyStr = keyStr;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public Integer getSize() {
        return size;
    }

    public void setSize(Integer size) {
        this.size = size;
    }

    public String getLanguage() {
        return language;
    }

    public void setLanguage(String language) {
        this.language = language;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }
}
